==> f-engine-0.0.4.tgz: package/es/canvas/render/animator.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _createSuper from "@babel/runtime/helpers/esm/createSuper";
import { omit, pick, isFunction } from '@antv/util';
import EE from '@antv/event-emitter';
import { createShape } from './createShape';
var Animator = /*#__PURE__*/function (_EE) {
  _inherits(Animator, _EE);
  var _super = _createSuper(Animator);
  function Animator() {
    _classCallCheck(this, Animator);
    return _super.apply(this, arguments);
  }
  _createClass(Animator, [{
    key: "animate",
    value: function animate(shape, start, end, effect) {
      this.shape = shape;
      this.start = start;
      this.end = end;
      this.effect = effect;
    }
  }, {
    key: "play",
    value: function play() {
      var _this = this;
      var shape = this.shape,
        start = this.start,
        end = this.end,
        effect = this.effect,
        children = this.children;
      var animations = [];
      if (effect) {
        var _effect$property = effect.property,
          property = _effect$property === void 0 ? [] : _effect$property,
          easing = effect.easing,
          duration = effect.duration,
          delay = effect.delay,
          iterations = effect.iterations,
          clip = effect.clip,
          onFrame = effect.onFrame,
          onEnd = effect.onEnd;
        // 应用样式
        var style = _objectSpread(_objectSpread({}, omit(end, property)), omit(start, property));
        Object.keys(style).forEach(function (key) {
          shape.setAttribute(key, style[key]);
        });
        // 开始帧
        var keyframeStart = property.reduce(function (prev, cur) {
          prev[cur] = start[cur];
          return prev;
        }, {});
        // 结束帧
        var keyframeEnd = pick(end, property);
        var animation = shape.animate([keyframeStart, keyframeEnd], {
          fill: 'both',
          easing: easing,
          duration: duration,
          delay: delay,
          iterations: iterations
        });
        animation.onframe = onFrame;
        animation.onfinish = onEnd;
        // 过滤无限循环的动画
        if (animation && iterations !== Infinity) {
          animations.push(animation.finished);
        }
        // clip 动画
        if (clip) {
          var clipConfig = isFunction(clip) ? clip(style) : clip;
          if (clipConfig) {
            var clipType = clipConfig.type,
              clipStyle = clipConfig.style,
              _clipConfig$property = clipConfig.property,
              clipProperty = _clipConfig$property === void 0 ? [] : _clipConfig$property,
              clipEasing = clipConfig.easing,
              clipDuration = clipConfig.duration,
              clipDelay = clipConfig.delay,
              clipIterations = clipConfig.iterations,
              clipStart = clipConfig.start,
              clipEnd = clipConfig.end;
            var clipStartStyle = _objectSpread(_objectSpread({}, clipStyle), clipStart);
            var clipEndStyle = _objectSpread(_objectSpread({}, clipStyle), clipEnd);
            // 开始帧
            var clipKeyframeStart = clipProperty.reduce(function (prev, cur) {
              prev[cur] = clipStartStyle[cur];
              return prev;
            }, {});
            // 结束帧
            var clipKeyframeEnd = pick(clipEndStyle, clipProperty);
            var clipShape = createShape(clipType, {
              style: clipStartStyle
            });
            shape.setAttribute('clipPath', clipShape);
            // g 中 clip 为全局，且如果要在 clip上加动画，需要手动加到canvas上
            shape.ownerDocument.documentElement.appendChild(clipShape);
            var clipAnimation = clipShape.animate([clipKeyframeStart, clipKeyframeEnd], {
              fill: 'both',
              easing: clipEasing || easing,
              duration: clipDuration || duration,
              delay: clipDelay || delay,
              iterations: clipIterations || iterations
            });
            // 过滤无限循环的动画
            if (clipAnimation && (clipIterations || iterations) !== Infinity) {
              var clipFinished = clipAnimation.finished;
              animations.push(clipFinished);
              clipFinished.then(function () {
                // 删掉 clip
                shape.setAttribute('clipPath', null);
              });
            }
          }
        }
      }
      if (children && children.length) {
        children.forEach(function (child) {
          if (!child) return;
          var childAnimator = child.play();
          if (childAnimator) {
            animations.push(childAnimator);
          }
        });
      }
      if (!animations.length) {
        this.emit('end');
        return null;
      }
      var finished = Promise.all(animations);
      finished.then(function () {
        _this.emit('end');
      });
      return finished;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.shape = null;
      this.start = null;
      this.end = null;
      this.effect = null;
      this.children = null;
    }
  }]);
  return Animator;
}(EE);
export default Animator;

==> f-engine-0.0.10.tgz: package/es/canvas/render/animator.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import _createSuper from "@babel/runtime/helpers/esm/createSuper";
import { omit, pick, isFunction } from '@antv/util';
import EE from '@antv/event-emitter';
import { createShape } from './createShape';
var Animator = /*#__PURE__*/function (_EE) {
  _inherits(Animator, _EE);
  var _super = _createSuper(Animator);
  function Animator() {
    _classCallCheck(this, Animator);
    return _super.apply(this, arguments);
  }
  _createClass(Animator, [{
    key: "animate",
    value: function animate(shape, start, end, effect) {
      this.shape = shape;
      this.start = start;
      this.end = end;
      this.effect = effect;
    }
  }, {
    key: "play",
    value: function play() {
      var _this = this;
      var shape = this.shape,
        start = this.start,
        end = this.end,
        effect = this.effect,
        children = this.children;
      var animations = [];
      if (effect) {
        var _effect$property = effect.property,
          property = _effect$property === void 0 ? [] : _effect$property,
          easing = effect.easing,
          duration = effect.duration,
          delay = effect.delay,
          iterations = effect.iterations,
          clip = effect.clip,
          _effect$onFrame = effect.onFrame,
          onFrame = _effect$onFrame === void 0 ? function () {} : _effect$onFrame,
          _effect$onEnd = effect.onEnd,
          onEnd = _effect$onEnd === void 0 ? function () {} : _effect$onEnd;
        // 应用样式
        var style = _objectSpread(_objectSpread({}, omit(end, property)), omit(start, property));
        Object.keys(style).forEach(function (key) {
          shape.setAttribute(key, style[key]);
        });
        // 开始帧
        var keyframeStart = property.reduce(function (prev, cur) {
          prev[cur] = start[cur];
          return prev;
        }, {});
        // 结束帧
        var keyframeEnd = pick(end, property);
        var animation = shape.animate([keyframeStart, keyframeEnd], {
          fill: 'both',
          easing: easing,
          duration: duration,
          delay: delay,
          iterations: iterations
        });
        if (animation) {
          animation.onframe = onFrame;
          animation.onfinish = onEnd;
        }
        // 过滤无限循环的动画
        if (animation && iterations !== Infinity) {
          animations.push(animation.finished);
        }
        // clip 动画
        if (clip) {
          var clipConfig = isFunction(clip) ? clip(style) : clip;
          if (clipConfig) {
            var clipType = clipConfig.type,
              clipStyle = clipConfig.style,
              _clipConfig$property = clipConfig.property,
              clipProperty = _clipConfig$property === void 0 ? [] : _clipConfig$property,
              clipEasing = clipConfig.easing,
              clipDuration = clipConfig.duration,
              clipDelay = clipConfig.delay,
              clipIterations = clipConfig.iterations,
              clipStart = clipConfig.start,
              clipEnd = clipConfig.end;
            var clipStartStyle = _objectSpread(_objectSpread({}, clipStyle), clipStart);
            var clipEndStyle = _objectSpread(_objectSpread({}, clipStyle), clipEnd);
            // 开始帧
            var clipKeyframeStart = clipProperty.reduce(function (prev, cur) {
              prev[cur] = clipStartStyle[cur];
              return prev;
            }, {});
            // 结束帧
            var clipKeyframeEnd = pick(clipEndStyle, clipProperty);
            var clipShape = createShape(clipType, {
              style: clipStartStyle
            });
            shape.setAttribute('clipPath', clipShape);
            // g 中 clip 为全局，且如果要在 clip上加动画，需要手动加到canvas上
            shape.ownerDocument.documentElement.appendChild(clipShape);
            var clipAnimation = clipShape.animate([clipKeyframeStart, clipKeyframeEnd], {
              fill: 'both',
              easing: clipEasing || easing,
              duration: clipDuration || duration,
              delay: clipDelay || delay,
              iterations: clipIterations || iterations
            });
            // 过滤无限循环的动画
            if (clipAnimation && (clipIterations || iterations) !== Infinity) {
              var clipFinished = clipAnimation.finished;
              animations.push(clipFinished);
              clipFinished.then(function () {
                // 删掉 clip
                shape.setAttribute('clipPath', null);
              });
            }
          }
        }
      }
      if (children && children.length) {
        children.forEach(function (child) {
          if (!child) return;
          var childAnimator = child.play();
          if (childAnimator) {
            animations.push(childAnimator);
          }
        });
      }
      if (!animations.length) {
        this.emit('end');
        return null;
      }
      var finished = Promise.all(animations);
      finished.then(function () {
        _this.emit('end');
      });
      return finished;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.shape = null;
      this.start = null;
      this.end = null;
      this.effect = null;
      this.children = null;
    }
  }]);
  return Animator;
}(EE);
export default Animator;
